package com.yx.face.controller.admin;


import com.baomidou.mybatisplus.core.metadata.IPage;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import com.yx.face.boot.component.security.Authority;
import com.yx.face.boot.restful.RestDTO;
import com.yx.face.boot.restful.RestResponse;
import com.yx.face.boot.restful.RestResult;
import com.yx.face.boot.uitls.AppTokenUtil;
import com.yx.face.boot.uitls.ClassUtil;
import com.yx.face.model.black.*;
import com.yx.face.service.UserBlackTaskService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;
import java.util.List;

/**
 * <p>
 * 黑名单任务列表 前端控制器
 * </p>
 *
 * @author wxg
 * @since 2024-08-31
 */
@Slf4j
@RestController
@Api(tags = {"1-黑名单任务"})
@ApiSupport(order = 10)
@Validated
@RequestMapping("admin/userBlackTask")
@RequiredArgsConstructor(onConstructor = @__(@Autowired))
public class UserBlackTaskController {

    private final UserBlackTaskService userBlackTaskService;

    @ApiOperation("任务-新增")
    @PostMapping("/insert")
    @ApiOperationSupport(order = 10)
    public RestResult<Boolean> insert(@RequestBody @Valid UserBlackTaskDto dto) {
        return RestResponse.ok(userBlackTaskService.insert(dto));
    }
    @ApiOperation("任务-绑定账号列表")
    @GetMapping("/adminList")
    @ApiOperationSupport(order = 20)
    public RestResult<List<AdminLessVo>> adminList() {
        return RestResponse.ok(userBlackTaskService.adminList());
    }

    @ApiOperation(value = "任务-分页列表")
    @PostMapping("getPageList")
    @ApiOperationSupport(order = 30)
    public RestResult<IPage<UserBlackTaskVo>> getPageList(@RequestBody RestDTO<UserBlackTaskSearch> dto) {
        ClassUtil.searchInit(dto,UserBlackTaskSearch.class);
        return RestResponse.ok(userBlackTaskService.getPageList(dto));
    }
    @ApiOperation("任务-删除")
    @GetMapping("/delete")
    @ApiOperationSupport(order = 40)
    public RestResult<Boolean> delete(@RequestParam("userBlackTaskId") Long userBlackTaskId) {
        return RestResponse.ok(userBlackTaskService.delete(userBlackTaskId));
    }
    @ApiOperation("任务-录入账号列表")
    @GetMapping("/enterAdminList")
    @ApiOperationSupport(order = 50)
    public RestResult<List<AdminLessVo>> enterAdminList() {
        return RestResponse.ok(userBlackTaskService.enterAdminList());
    }

    @ApiOperation(value = "黑名单-分页列表")
    @PostMapping("user/getPageList")
    @ApiOperationSupport(order = 60)
    public RestResult<IPage<UserBlackVo>> userGetPageList(@RequestBody RestDTO<UserBlackSearch> dto) {
        ClassUtil.searchInit(dto,UserBlackSearch.class);
        return RestResponse.ok(userBlackTaskService.userGetPageList(dto));
    }
    @ApiOperation("黑名单-删除")
    @GetMapping("user/delete")
    @ApiOperationSupport(order = 70)
    public RestResult<Boolean> userDelete(@RequestParam("userBlackListId") Long userBlackListId) {
        return RestResponse.ok(userBlackTaskService.userDelete(userBlackListId));
    }
    @ApiOperation("设备获取黑名单列表")
    @PostMapping("device/getBlackList")
    @ApiOperationSupport(order = 80)
    @Authority(required = false)
    public RestResult<List<DeviceBlackVo>> getBlackList(@RequestBody @Valid DeviceBlackDto dto) {
        List<String> tokens = AppTokenUtil.getTokens();
        if (!tokens.contains(dto.getToken())) {
            return RestResponse.error("token无效");
        }
        return userBlackTaskService.getBlackList(dto);
    }
    @ApiOperation("设备获取黑名单列表-加密")
    @PostMapping("device/encry/getBlackList")
    @ApiOperationSupport(order = 90)
    @Authority(required = false)
    public RestResult<ThirdPlatformSm4DTO> getEncryBlackList(@RequestBody @Valid ThirdPlatformSm4DTO dto) {
        return userBlackTaskService.getEncryBlackList(dto);
    }

}
